@@ -418,10 +418,14 @@ sub copy_image {
     my $image = ref $imageId && $imageId->isa('VM::EC2::Image') ? $imageId 
   	                                                        : $ec2->describe_images($imageId);
     $image       
-	or croak "Unknown image '$imageId'";
+	or  croak "Unknown image '$imageId'";
     $image->imageType eq 'machine' 
-	or croak "$image is not an AMI";
-    
+	or  croak "$image is not an AMI";
+    $image->platform eq 'windows'
+	and croak "It is not currently possible to migrate Windows images between regions via this method";
+    $image->rootDeviceType eq 'ebs'
+	or croak "It is not currently possible to migrate instance-store backed images between regions via this method";
+        
     my $dest_manager;
     if (ref $destination && $destination->isa('VM::EC2::Staging::Manager')) {
 	$dest_manager = $destination;
@@ -527,13 +531,17 @@ sub _copy_ebs_image {
     my $name         = $info->{name};
     my $description  = $info->{description};
     my $architecture = $info->{architecture};
-    my $kernel       = $self->_match_kernel($info->{kernel},$dest_manager,'kernel')
-	or croak "Could not find an equivalent kernel for $info->{kernel} in region ",$dest_manager->ec2->endpoint;
+    my ($kernel,$ramdisk);
+
+    if ($info->{kernel}) {
+	$kernel       = $self->_match_kernel($info->{kernel},$dest_manager,'kernel')
+	    or croak "Could not find an equivalent kernel for $info->{kernel} in region ",$dest_manager->ec2->endpoint;
+    }
     
-    my $ramdisk;
     if ($info->{ramdisk}) {
 	$ramdisk      = $self->_match_kernel($info->{ramdisk},$dest_manager,'ramdisk')
-	    or croak "Could not find an equivalent ramdisk for $info->{ramdisk} in region ",$dest_manager->ec2->endpoint;	    }
+	    or croak "Could not find an equivalent ramdisk for $info->{ramdisk} in region ",$dest_manager->ec2->endpoint;
+    }
 
     my $block_devices   = $info->{block_devices};  # format same as $image->blockDeviceMapping
     my $root_device     = $info->{root_device};
@@ -587,8 +595,8 @@ sub _copy_ebs_image {
 						  -block_device_mapping => \@mappings,
 						  -description          => $description,
 						  -architecture         => $architecture,
-						  -kernel_id            => $kernel,
-						  $ramdisk ? (-ramdisk_id  => $ramdisk): ()
+						  $kernel  ? (-kernel_id   => $kernel):  (),
+						  $ramdisk ? (-ramdisk_id  => $ramdisk): (),
 	);
     $img or croak "Could not register image: ",$dest_manager->ec2->error_str;
 
@@ -1271,17 +1279,30 @@ sub dd {
     my ($vol1,$vol2) = @_;
     my ($server1,$device1) = ($vol1->server,$vol1->mtdev);
     my ($server2,$device2) = ($vol2->server,$vol2->mtdev);
-    my $hush     = $self->verbosity < VERBOSE_DEBUG ? '2>/dev/null' : '';
+    my $hush     = $self->verbosity <  VERBOSE_INFO ? '2>/dev/null' : '';
+    my $use_pv   = $self->verbosity >= VERBOSE_WARN;
+    my $gigs     = $vol1->size;
+
+    if ($use_pv) {
+	$self->info('Configuring PV to show dd progress.');
+	$server1->ssh("if [ ! -e /usr/bin/pv ]; then sudo apt-get -qq update; sudo apt-get -y -qq install pv; fi");
+    }
 
     if ($server1 eq $server2) {
-	$server1->ssh("sudo dd if=$device1 of=$device2 $hush");
+	if ($use_pv) {
+	    print STDERR "\n";
+	    $server1->ssh("sudo dd if=$device1 2>/dev/null | pv -f -s ${gigs}G -petr | sudo dd of=$device2 2>/dev/null");
+	} else {
+	    $server1->ssh("sudo dd if=$device1 of=$device2 $hush");
+	}
     }  else {
 	my $keyname  = $self->_authorize($server1,$server2);
 	my $dest_ip  = $server2->instance->dnsName;
 	my $ssh_args = $server1->_ssh_escaped_args;
 	my $keyfile  = $server1->keyfile;
 	$ssh_args    =~ s/$keyfile/$keyname/;  # because keyfile is embedded among args
-	$server1->ssh("sudo dd if=$device1 $hush | gzip -1 - | ssh $ssh_args $dest_ip 'gunzip -1 - | sudo dd of=$device2 $hush'");
+	my $pv       = $use_pv ? "| pv -s ${gigs}G -petr" : '';
+	$server1->ssh("sudo dd if=$device1 $hush $pv | gzip -1 - | ssh $ssh_args $dest_ip 'gunzip -1 - | sudo dd of=$device2 $hush'");
     }
 }
 
@@ -1783,17 +1804,17 @@ sub _scan_volumes {
 	$args{-name}     = $volume->tags->{StagingName};
 	$args{-fstype}   = $volume->tags->{StagingFsType};
 	$args{-mtpt}     = $volume->tags->{StagingMtPt};
+	my $mounted;
 
 	if (my $attachment = $volume->attachment) {
 	    my $server = $self->find_server_by_instance($attachment->instance);
-	    $args{-server} = $server;
+	    $args{-server}   = $server;
+	    ($args{-mtdev},$mounted)  = $server->ping &&
+		                        $server->_find_mount($attachment->device);
 	}
 
 	my $vol = $self->volume_class()->new(%args);
-	if ($args{-mtpt} && $args{-server}) {
-	    $vol->mounted(1) if $args{-server}->ping && 
-		             $args{-server}->scmd('cat /etc/mtab')=~ $args{-mtpt};
-	}
+	$vol->mounted(1) if $mounted;
 	$self->register_volume($vol);
     }
 }
@@ -1999,6 +2020,9 @@ sub _gather_image_info {
 	root_device  =>   $image->rootDeviceName,
 	block_devices=>   [$image->blockDeviceMapping],
 	is_public    =>   $image->isPublic,
+	platform     =>   $image->platform,
+	virtualizationType => $image->virtualizationType,
+	hypervisor         => $image->hypervisor,
 	authorized_users => [$image->authorized_users],
     };
 }
